==> bootstrap-vue-2.0.0-rc.21.jar: META-INF/resources/webjars/bootstrap-vue/2.0.0-rc.21/README.md <==
<p align="center">
  <a href="https://bootstrap-vue.js.org">
    <img src="https://github.com/bootstrap-vue/bootstrap-vue/raw/master/static/banner.png" width="300">
  </a>
</p>
<br>

<p align="center">
  BootstrapVue, with over 40 available plugins and more than 75 custom components, provides
  one of the most comprehensive implementations of the Bootstrap 4.3 component and grid
  system for Vue.js, complete with extensive and automated WAI-ARIA accessibility markup.
</p>
<br>

<p align="center">
  <a href="https://www.npmjs.com/package/bootstrap-vue">
    <img src="https://flat.badgen.net/npm/v/bootstrap-vue" alt="Current version">
  </a>
  <a href="https://getbootstrap.com/docs">
    <img src="https://flat.badgen.net/badge/bootstrap/4.3.x/563d7c" alt="Bootstrap version">
  </a>
  <a href="https://vuejs.org">
    <img src="https://flat.badgen.net/badge/vue.js/2.6.x/4fc08d" alt="Vue.js version">
  </a>
  <a href="https://circleci.com/gh/bootstrap-vue/bootstrap-vue">
    <img src="https://flat.badgen.net/circleci/github/bootstrap-vue/bootstrap-vue/master?label=build" alt="CircleCI status">
  </a>
  <a href="https://github.com/bootstrap-vue/bootstrap-vue">
    <img src="https://flat.badgen.net/david/dep/bootstrap-vue/bootstrap-vue" alt="Dependencies status">
  </a>
  <br>
  <a href="https://codecov.io/gh/bootstrap-vue/bootstrap-vue">
    <img src="https://flat.badgen.net/codecov/c/github/bootstrap-vue/bootstrap-vue" alt="Coverage">
  </a>
  <a href="http://packagequality.com/#?package=bootstrap-vue">
    <img src="https://npm.packagequality.com/shield/bootstrap-vue.svg?style=flat-square" alt="Package quality">
  </a>
  <a href="https://www.npmjs.com/package/bootstrap-vue">
    <img src="https://flat.badgen.net/npm/dt/bootstrap-vue" alt="npm downloads">
  </a>
  <a href="https://www.npmjs.com/package/bootstrap-vue">
    <img src="https://flat.badgen.net/npm/dw/bootstrap-vue" alt="npm monthly downloads">
  </a>
  <br>
  <a href="https://opencollective.com/bootstrap-vue#sponsor">
    <img src="https://opencollective.com/bootstrap-vue/sponsors/badge.svg?style=flat-square" alt="Open Collective sponsors">
  </a>
  <a href="https://opencollective.com/bootstrap-vue#backer">
    <img src="https://flat.badgen.net/opencollective/backers/bootstrap-vue" alt="Open Collective backers">
  </a>
  <a href="https://opencollective.com/bootstrap-vue">
    <img src="https://flat.badgen.net/opencollective/balance/bootstrap-vue" alt="Open Collective balance">
  </a>
</p>

<h2 align="center">Links</h2>

- 📘 [Documentation](https://bootstrap-vue.js.org)
- 🔨 [Release Notes](https://bootstrap-vue.js.org/docs/misc/changelog)
- 💬 [Discord Chat](https://discord.gg/j2Mtcny)
- 🐦 [Twitter](https://twitter.com/BootstrapVue)

<h2 align="center">Sponsors</h2>

Support this project by becoming a sponsor.

Your logo will show up here with a link to your website.
[[Become a sponsor](https://opencollective.com/bootstrap-vue#sponsor)]

<a href="https://opencollective.com/bootstrap-vue/sponsor/0/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/1/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/2/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/3/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/4/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/5/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/6/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/7/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/8/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/9/website" target="_blank"><img src="https://opencollective.com/bootstrap-vue/sponsor/9/avatar.svg"></a>

<h2 align="center">Backers</h2>

Thank you to all our backers! 🙏
[[Become a backer](https://opencollective.com/bootstrap-vue#backer)]

<a href="https://opencollective.com/bootstrap-vue#backers" target="_blank"><img src="https://opencollective.com/bootstrap-vue/backers.svg?width=890"></a>

<h2 align="center">Contributors</h2>

This project exists thanks to all the people who contribute. [[Contribute]](CONTRIBUTING.md).

<a href="https://github.com/bootstrap-vue/bootstrap-vue/graphs/contributors"><img src="https://opencollective.com/bootstrap-vue/contributors.svg?width=890"></a>

<h2 align="center">License</h2>

Released under the MIT [License](./LICENSE). Copyright (c) BootstrapVue.

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bhttps%3A%2F%2Fgithub.com%2Fbootstrap-vue%2Fbootstrap-vue.svg?type=small)](https://app.fossa.io/projects/git%2Bhttps%3A%2F%2Fgithub.com%2Fbootstrap-vue%2Fbootstrap-vue?ref=badge_small)

==> bootstrap-vue-2.4.0.jar: META-INF/resources/webjars/bootstrap-vue/2.4.0/README.md <==
<p align="center">
  <a href="https://bootstrap-vue.js.org">
    <img src="https://github.com/bootstrap-vue/bootstrap-vue/raw/master/static/banner.png" width="300">
  </a>
</p>
<br>

<p align="center">
  BootstrapVue, with over 40 available plugins, more than 80 custom components, and over 300 icons,
  provides one of the most comprehensive implementations of the Bootstrap v4.3 component and grid
  system for Vue.js, complete with extensive and automated WAI-ARIA accessibility markup.
</p>
<br>

<p align="center">
  <a href="https://www.npmjs.com/package/bootstrap-vue">
    <img src="https://flat.badgen.net/npm/v/bootstrap-vue" alt="Current version">
  </a>
  <a href="https://getbootstrap.com/docs">
    <img src="https://flat.badgen.net/badge/bootstrap/4.3.x/563d7c" alt="Bootstrap version">
  </a>
  <a href="https://vuejs.org">
    <img src="https://flat.badgen.net/badge/vue.js/2.6.x/4fc08d" alt="Vue.js version">
  </a>
  <a href="https://circleci.com/gh/bootstrap-vue/bootstrap-vue">
    <img src="https://flat.badgen.net/circleci/github/bootstrap-vue/bootstrap-vue/master?label=build" alt="CircleCI status">
  </a>
  <a href="https://github.com/bootstrap-vue/bootstrap-vue">
    <img src="https://flat.badgen.net/david/dep/bootstrap-vue/bootstrap-vue" alt="Dependencies status">
  </a>
  <br>
  <a href="https://codecov.io/gh/bootstrap-vue/bootstrap-vue">
    <img src="https://flat.badgen.net/codecov/c/github/bootstrap-vue/bootstrap-vue" alt="Coverage">
  </a>
  <a href="http://packagequality.com/#?package=bootstrap-vue">
    <img src="https://npm.packagequality.com/shield/bootstrap-vue.svg?style=flat-square" alt="Package quality">
  </a>
  <a href="https://www.npmjs.com/package/bootstrap-vue">
    <img src="https://flat.badgen.net/npm/dt/bootstrap-vue" alt="npm downloads">
  </a>
  <a href="https://www.npmjs.com/package/bootstrap-vue">
    <img src="https://flat.badgen.net/npm/dw/bootstrap-vue" alt="npm monthly downloads">
  </a>
  <br>
  <a href="https://opencollective.com/bootstrap-vue#sponsor">
    <img src="https://opencollective.com/bootstrap-vue/sponsors/badge.svg?style=flat-square" alt="Open Collective sponsors">
  </a>
  <a href="https://opencollective.com/bootstrap-vue#backer">
    <img src="https://flat.badgen.net/opencollective/backers/bootstrap-vue" alt="Open Collective backers">
  </a>
  <a href="https://opencollective.com/bootstrap-vue">
    <img src="https://flat.badgen.net/opencollective/balance/bootstrap-vue" alt="Open Collective balance">
  </a>
</p>

<h2 align="center">Links</h2>

- 📘 [Documentation](https://bootstrap-vue.js.org)
- 🔨 [Release Notes](https://bootstrap-vue.js.org/docs/misc/changelog)
- 💬 [Discord Chat](https://discord.gg/j2Mtcny)
- 🐦 [Twitter](https://twitter.com/BootstrapVue)

<h2 align="center">Sponsors</h2>

Support this project by becoming a sponsor.

Your logo will show up here with a link to your website.
[[Become a sponsor](https://opencollective.com/bootstrap-vue#sponsor)]

<a href="https://opencollective.com/bootstrap-vue/sponsor/0/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/1/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/2/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/3/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/4/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/5/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/6/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/7/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/8/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/bootstrap-vue/sponsor/9/website" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/sponsor/9/avatar.svg"></a>

<h2 align="center">Backers</h2>

Thank you to all our backers! 🙏
[[Become a backer](https://opencollective.com/bootstrap-vue#backer)]

<a href="https://opencollective.com/bootstrap-vue#backers" target="_blank" rel="noopener"><img src="https://opencollective.com/bootstrap-vue/backers.svg?width=890"></a>

<h2 align="center">Contributors</h2>

This project exists thanks to all the people who contribute. [[Contribute]](CONTRIBUTING.md).

<a href="https://github.com/bootstrap-vue/bootstrap-vue/graphs/contributors"><img src="https://opencollective.com/bootstrap-vue/contributors.svg?width=890"></a>

<h2 align="center">License</h2>

Released under the MIT [License](./LICENSE). Copyright (c) BootstrapVue.

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bhttps%3A%2F%2Fgithub.com%2Fbootstrap-vue%2Fbootstrap-vue.svg?type=small)](https://app.fossa.io/projects/git%2Bhttps%3A%2F%2Fgithub.com%2Fbootstrap-vue%2Fbootstrap-vue?ref=badge_small)
